@@ -1,7 +1,7 @@
-mod payload;
-
 use url::Url;
 
+use crate::payload;
+
 pub fn query(url: String) -> Vec<String> {
 	let payload = payload::get();
 
